<?php
/*
Plugin Name: Course Catalog System
Plugin URI: http://www.nizma.com.my/
Description: Fetches the content of Course Catalog System to display inside the current post or page.
Author: Hairulnizam Zulkefli
Author URI: http://www.nizma.com.my/
Tags: wordpress, catalog
Version: 1.0.3
*/

define('CCS_OPTION_NAME', 'ccs_option_name');
define('CCS_PLUGIN_FILE', __FILE__);					// This file name
define('CCS_PLUGIN_PATH', plugin_dir_path(__FILE__));	// Path to this plugin, with trailing '/'
define('CCS_SEARCH_FORM', plugin_dir_path(__FILE__) . 'search-form.php');
define('CCS_SEARCH_RESULT', plugin_dir_path(__FILE__) . 'search-result.php');
define('CCS_SEARCH_NO_RESULT', plugin_dir_path(__FILE__) . 'search-no-result.php');
define('CCS_SEARCH_BOX', plugin_dir_path(__FILE__) . 'search-box.php');
define('CCS_SEARCH_BOX_DUMMY', plugin_dir_path(__FILE__) . 'search-box-dummy.php');
define('CCS_SEARCH_RESULT_TOP', plugin_dir_path(__FILE__) . 'search-result-box-top.php');
define('CCS_SEARCH_RESULT_BOTTOM', plugin_dir_path(__FILE__) . 'search-result-box-bottom.php');

require CCS_PLUGIN_PATH . 'ccs-options.php';

/**
 * Function using all available methods to open remote site and return content
 * - file_get_contents()
 * - cURL
 */
function ccs_get_content_curl($url)
{
    $response = array();

    $response['url'] = $url;

    if (function_exists('file_get_contents'))
    {
        $html = @file_get_contents($url);

        if ($html !== FALSE)
        {
            $response['http_code'] = 200;
            $response['method'] = 'file_get_contents';
            $response['html'] = $html;

            return $response;
        }
    }

    if (is_callable('curl_init'))
    {
        $referer = get_bloginfo('url');
        $timeout = 30;

        $curl = curl_init();

        if (strstr($referer, "://"))
        {
            curl_setopt ($curl, CURLOPT_REFERER, $referer);
        }

        curl_setopt($curl, CURLOPT_URL, $url);
        curl_setopt($curl, CURLOPT_HTTPGET, TRUE);			// reset the HTTP request method to GET
        curl_setopt($curl, CURLOPT_TIMEOUT, $timeout);		// maximum number of seconds to allow cURL functions to execute
        curl_setopt($curl, CURLOPT_CONNECTTIMEOUT, 7);		// number of seconds to wait while trying to connect
        curl_setopt($curl, CURLOPT_USERAGENT, sprintf("Mozilla/%d.0", rand(4, 5)));
        curl_setopt($curl, CURLOPT_HEADER, FALSE);			// exclude the header in the output
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, TRUE);	// return the transfer as a string of the return value instead of output
        curl_setopt($curl, CURLOPT_FOLLOWLOCATION, TRUE);
        curl_setopt($curl, CURLOPT_MAXREDIRS, 10);

        if (substr($url, 0, 5) == 'https')
        {
            curl_setopt($curl, CURLOPT_SSLVERSION, 3);			// Supports only SSL version 3
            curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, TRUE);	// verify the peer's certificate
        }
        else
        {
            curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, FALSE);
        }

        $html = curl_exec($curl);
        $http_code = curl_getinfo($curl, CURLINFO_HTTP_CODE);

        if ( ! curl_errno($curl))
        {
            $response['http_code'] = 200;
            $response['method'] = 'curl';
            $response['html'] = $html;

            curl_close($curl);

            return $response;
        }
        else
        {
            $response['http_code'] = curl_errno($curl);
            $response['method'] = 'curl';
            $response['html'] = curl_error($curl);

            curl_close($curl);

            return $response;
        }
    }
    else
    {
        $response['http_code'] = 403;
        $response['method'] = '';
        $response['html'] = 'cURL is not available';

        return $response;
    }
}

/**
 * Function using cURL and post data to remote site and return content
 */
function ccs_post_content_curl($url, $data)
{
    $response = array();

    $response['url'] = $url;

    if (is_callable('curl_init'))
    {
        $referer = get_bloginfo('url');
        $timeout = 30;

        $curl = curl_init();

        if (strstr($referer, "://"))
        {
            curl_setopt ($curl, CURLOPT_REFERER, $referer);
        }

        curl_setopt($curl, CURLOPT_URL, $url);
        curl_setopt($curl, CURLOPT_POSTFIELDS, $data);
        curl_setopt($curl, CURLOPT_TIMEOUT, $timeout);		// maximum number of seconds to allow cURL functions to execute
        curl_setopt($curl, CURLOPT_CONNECTTIMEOUT, 7);		// number of seconds to wait while trying to connect
        curl_setopt($curl, CURLOPT_USERAGENT, sprintf("Mozilla/%d.0", rand(4, 5)));
        curl_setopt($curl, CURLOPT_HEADER, FALSE);			// exclude the header in the output
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, TRUE);	// return the transfer as a string of the return value instead of output
        curl_setopt($curl, CURLOPT_FOLLOWLOCATION, TRUE);
        curl_setopt($curl, CURLOPT_MAXREDIRS, 10);

        if (substr($url, 0, 5) == 'https')
        {
            curl_setopt($curl, CURLOPT_SSLVERSION, 3);			// Supports only SSL version 3
            curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, TRUE);	// verify the peer's certificate
        }
        else
        {
            curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, FALSE);
        }

        $html = curl_exec($curl);
        $http_code = curl_getinfo($curl, CURLINFO_HTTP_CODE);

        if ( ! curl_errno($curl))
        {
            $response['http_code'] = 200;
            $response['method'] = 'curl';
            $response['html'] = $html;

            curl_close($curl);

            return $response;
        }
        else
        {
            $response['http_code'] = curl_errno($curl);
            $response['method'] = 'curl';
            $response['html'] = curl_error($curl);

            curl_close($curl);

            return $response;
        }
    }
    else
    {
        $response['http_code'] = 403;
        $response['method'] = '';
        $response['html'] = 'cURL is not available';

        return $response;
    }
}

/**
 * Function calling above function (ccs_get_content_curl) to open remote site and return content only if successful,
 * upon failure return nothing ('')
 *
 * -- Not used
 */
function ccs_get_content($atts)
{
    $response = ccs_get_content_curl($atts);

    if ($response['http_code'] == 200)
    {
        return $response['html'];
    }
    else
    {
        return '';
    }
}
add_shortcode('ccs_get_content', 'ccs_get_content');

/**
 * Function to open url and return JSON data in json_decoded format.
 * This is local function and not to be used as plugin function
 */
function get_json_content($url = '')
{
    if ( ! empty($url))
    {
        $options = get_option(CCS_OPTION_NAME);
        $ccs_url = $options['ccs_url'];

        $remote_url = $ccs_url . $url;
        $response = ccs_get_content_curl($remote_url);

        if (isset($response['html']))
        {
            $json_data = $response['html'];
            return json_decode($json_data);
        }
    }

    return array();
}

/**
 * List of faculties - with a building image, and 4 buttons:
 * - Academic Programme - List of programmes of a faculty
 * - Expertise
 * - Download Brochure
 * - Visit Website
 */
function ccs_render_faculty_list($atts)
{
    // /api/wordpress/faculties

    if (defined('ICL_LANGUAGE_CODE'))
    {
        $lang = ICL_LANGUAGE_CODE;
    }
    else
    {
        if (function_exists('qtranxf_getLanguage'))
        {
            $lang = qtranxf_getLanguage();
        }
        else
        {
            $lang = 'en';
        }
    }

    // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
    // Each __() function must be __('Words to translate', 'course-catalog-system')
    load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

    $options = get_option(CCS_OPTION_NAME);
    $ccs_url = $options['ccs_url'];
    $ccs_faculty_program_page = $options['ccs_faculty_program_page'];
    $ccs_faculty_id_param = $options['ccs_faculty_id_param'];
    $ccs_header_colors = $options['ccs_header_colors'];
    $ccs_header_colors = explode(',', $ccs_header_colors);
    if (count($ccs_header_colors) == 0)
    {
        $ccs_header_colors = array('#1f86c1', '#dd3333');
    }

    $remote_url = $ccs_url . '/api/wordpress/faculties/' . $lang;
    $response = ccs_get_content_curl($remote_url);

    $json_data = $response['html'];
    $faculties = json_decode($json_data);

    if (count($faculties) > 0)
    {
        $output = '';
        $faculty_count = 0;

        foreach ($faculties as $faculty)
        {
            $faculty_count++;
            $color_index = $ccs_header_colors[($faculty_count % count($ccs_header_colors))];

            $output .= '<div class="col-md-12 aligncenter faculty-header" style="background-color:' . $color_index . ';">';
            $output .= '<h2 style="text-transform: uppercase;">';
            $output .= $faculty->faculty_name;
            if ( ! empty($faculty->faculty_code))
            {
                $output .= ' (' . $faculty->faculty_code . ')';
            }
            $output .= '</h2>';
            $output .= '</div>';

            $output .= '<div class="col-md-12">&nbsp;</div>';

            $output .= '<div class="col-md-8" style="text-align: right;">';
                $output .= '<img src="' . plugins_url('images/img1.jpg', __FILE__) . '" alt="">';
                $output .= '<div class="col-xs-12">&nbsp;</div>';
            $output .= '</div>';

            $output .= '<div class="col-md-4 faculty-buttons">';
                $output .= '<div class="col-xs-6" style="min-height: 130px;">';
                    $output .= '<a href="' . get_site_url() . $ccs_faculty_program_page . '?' . $ccs_faculty_id_param . '=' . $faculty->faculty_id . '">';
                    $output .= '<i class="fa fa-graduation-cap"></i>' . '<br>';
                    $output .= __('ACADEMIC PROGRAMME', 'course-catalog-system');
                    $output .= '</a>';
                $output .= '</div>';

                $output .= '<div class="col-xs-6" style="min-height: 130px;">';
                    $output .= '<a href="">';
                    $output .= '<i class="fa fa-lightbulb-o"></i>' . '<br>';
                    $output .= __('EXPERTISE', 'course-catalog-system');
                    $output .= '</a>';
                $output .= '</div>';

                $output .= '<br class="clearfix">';

                $output .= '<div class="col-xs-6" style="min-height: 130px;">';
                    $output .= '<a href="">';
                    $output .= '<i class="fa fa-download"></i>' . '<br>';
                    $output .= __('DOWNLOAD BROCHURE', 'course-catalog-system');
                    $output .= '</a>';
                $output .= '</div>';

                $output .= '<div class="col-xs-6" style="min-height: 130px;">';
                    $output .= '<a href="">';
                    $output .= '<i class="fa fa-chain"></i>' . '<br>';
                    $output .= __('VISIT WEBSITE', 'course-catalog-system');
                    $output .= '</a>';
                $output .= '</div>';
            $output .= '</div>';
        }

        return $output . eol();
    }
    else
    {
        return eol();
    }
}
add_shortcode('ccs_render_faculty_list', 'ccs_render_faculty_list');

/**
 * Function to show list of programmes (by level of study - optional)
 */
function ccs_render_program_list($atts = null)
{
    // /api/wordpress/programs/{studylevel}/{lang}

    if ( ! empty($atts))
    {
        $attributes = shortcode_atts(array(
            'studylevel_id' => ''			// Default to Undergraduate Studies
        ), $atts);
    }
    else
    {
        $attributes['studylevel_id'] = '';
    }

    $studylevel_id = $attributes['studylevel_id'];

    if (defined('ICL_LANGUAGE_CODE'))
    {
        $lang = ICL_LANGUAGE_CODE;
    }
    else
    {
        if (function_exists('qtranxf_getLanguage'))
        {
            $lang = qtranxf_getLanguage();
        }
        else
        {
            $lang = 'en';
        }
    }

    // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
    // Each __() function must be __('Words to translate', 'course-catalog-system')
    load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

    $options = get_option(CCS_OPTION_NAME);
    $ccs_url = $options['ccs_url'];
    $ccs_program_id_param = $options['ccs_program_id_param'];
    $ccs_program_details_page = $options['ccs_program_details_page'];

    $remote_url = $ccs_url . '/api/wordpress/programs_count/' . $studylevel_id . '/' . $lang;
    $response = ccs_get_content_curl($remote_url);

    $json_data = $response['html'];
    $faculties = json_decode($json_data);		// Program count

    $output = '';

    if (count($faculties) > 0)
    {
        $remote_url = $ccs_url . '/api/wordpress/programs/' . $studylevel_id . '/' . $lang;

        $response = ccs_get_content_curl($remote_url);

        $json_data = $response['html'];
        $programs = json_decode($json_data);

        if (count($programs) > 0)
        {
            if ($studylevel_id == '11')
            {
                //   '10' - By Research
                // '1000' - By Coursework
                // '1010' - Mixed Mode
                $study_modes = array('0', '10', '1000', '1010');
                $study_mode_title = array(
                    '0'    => '',
                    '10'   => __('By Research', 'course-catalog-system'),
                    '1000' => __('By Coursework', 'course-catalog-system'),
                    '1010' => __('By Mixed Mode', 'course-catalog-system')
                );
                $study_mode_count = array();

                foreach ($study_modes as $study_mode)
                {
                    $scnt = 0;
                    foreach ($programs as $program)
                    {
                        if ($program->program_research_coursework == $study_mode)
                        {
                            $scnt++;
                        }
                    }
                    $study_mode_count[$study_mode] = $scnt;
                }

                $count_local = 0;
                //$program_count = 0;

                foreach ($study_modes as $study_mode)
                {
                    $program_count = 0;

                    if ($study_mode_count[$study_mode] > 0)
                    {
                        $output .= "\n";
                        if ($study_mode_title[$study_mode] != '')
                        {
                            $output .= '<h3>' . $study_mode_title[$study_mode] . '</h3>';
                        }
                        $output .= '<div class="table-1">';
                        $output .= '<table class="ccs-program-table" width="100%">' . "\n";
                        $output .= '<thead>';
                        $output .= '<tr>';
                        $output .= '<th style="width: 5%;">&nbsp;</th>';
                        $output .= '<th>' . __('Programme', 'course-catalog-system') . '</th>';
                        $output .= '<th style="width: 45%;">' . __('Faculty', 'course-catalog-system') . '</th>';
                        $output .= '</tr>';
                        $output .= '</thead>' . "\n";
                        $output .= '<tbody>' . "\n";

                        foreach ($faculties as $faculty)
                        {
                            $row = 1;

                            foreach ($programs as $program)
                            {

                                if ($program->faculty_id == $faculty->faculty_id &&
                                    $program->program_research_coursework == $faculty->program_research_coursework &&
                                    $program->program_research_coursework == $study_mode)
                                {
                                    $program_count++;

                                    $output .= '<tr>';
                                    $output .= '<td style="text-align: center;">' . $program_count . '</td>';

                                    $output .= '<td>';

                                    if ($program->program_scope == 'L')
                                    {
                                        $output .= '<span style="color:red;">*</span>&nbsp;';
                                        $count_local++;
                                    }

                                    if ( ! empty($program->program_code))
                                    {
                                        $output .= $program->program_code . ': ';
                                    }

                                    $output .= '<a href="' . get_site_url() . $ccs_program_details_page . '?' . $ccs_program_id_param . '=' . $program->program_id . '">';
                                    $output .= $program->program_name;
                                    $output .= '</a>';

                                    $output .= '</td>';

//                                    $output .= '<td>';
//                                    $output .= ( ! empty($faculty->faculty_name) ? $faculty->faculty_name : '&nbsp;');
//                                    $output .= '</td>';

                                    // Using rowspan
                                    if ($row == 1)
                                    {
                                        $output .= '<td rowspan="' . $faculty->program_count . '" style="background-color: #ffffff;">';	// rowspan required for styling (even for 1 row)
                                        $output .= ( ! empty($faculty->faculty_name) ? $faculty->faculty_name : '&nbsp;');
                                        $output .= '</td>';
                                    }

                                    $output .= '</tr>' . "\n";
                                    $row++;
                                }
                            }
                            //$output .= '</tr>' . "\n";
                        }

                        $output .= '</tbody>' . "\n";
                        $output .= '</table>' . "\n";
                        $output .= '</div>' . "\n";
                        $output .= '<br>';
                    }
                }

                if ($count_local > 0)
                {
                    $output .= '<div class="ccs-text">';
                    $output .= __('Programme marked (', 'course-catalog-system');
                    $output .= '<span style="color:red;">*</span>';
                    //$output .= __(') are available for Malaysian students only', 'course-catalog-system');
                    $output .= __(') are not available for international students', 'course-catalog-system');
                    $output .= '</div>';
                }

                return $output . eol();
            }
            else if ($studylevel_id == '12')
            {
                // Undergraduate Studies

                $output  = "\n";
                $output .= '<div class="table-1">';
                $output .= '<table class="ccs-program-table" width="100%">' . "\n";
                $output .= '<thead>';
                $output .= '<tr>';
                $output .= '<th style="width: 5%;">&nbsp;</th>';
                $output .= '<th>' . __('Programme', 'course-catalog-system') . '</th>';
                $output .= '<th style="width: 45%;">' . __('Faculty', 'course-catalog-system') . '</th>';
                $output .= '</tr>';
                $output .= '</thead>' . "\n";
                $output .= '<tbody>' . "\n";

                $count_local = 0;
                $program_count = 0;

                foreach ($faculties as $faculty)
                {
                    if ( ! empty($faculty->faculty_name))
                    {
                        $row = 1;

                        foreach ($programs as $program)
                        {
                            if ($program->faculty_id == $faculty->faculty_id)
                            {
                                $program_count++;

                                $output .= '<tr>';
                                $output .= '<td style="text-align: center;">' . $program_count . '</td>';

                                $output .= '<td>';

                                if ($program->program_scope == 'L')
                                {
                                    $output .= '<span style="color:red;">*</span>&nbsp;';
                                    $count_local++;
                                }
                                if ( ! empty($program->program_code))
                                {
                                    $output .= $program->program_code . ': ';
                                }

                                $output .= '<a href="' . get_site_url() . $ccs_program_details_page . '?' . $ccs_program_id_param . '=' . $program->program_id . '">';
                                $output .= $program->program_name;
                                $output .= '</a>';

                                $output .= '</td>';

                                if ($row == 1)
                                {
                                    $output .= '<td rowspan="' . $faculty->program_count . '" style="background-color: #ffffff;">';		// rowspan required for styling (even for 1 row)
                                    $output .= $faculty->faculty_name;
                                    $output .= '</td>';
                                }

//                                $output .= '<td>';
//                                $output .= $faculty->faculty_name;
//                                $output .= '</td>';

                                $output .= '</tr>' . "\n";
                                $row++;
                            }
                        }
                        $output .= '</tr>' . "\n";
                    }
                }

                $output .= '</tbody>' . "\n";
                $output .= '</table>' . "\n";
                $output .= '</div>' . "\n";
                $output .= '<br>';

                $output .= '<div class="ccs-text">';
                $output .= __('Programme marked (', 'course-catalog-system');
                $output .= '<span style="color:red;">*</span>';
                //$output .= __(') are available for Malaysian students only', 'course-catalog-system');
                $output .= __(') are not available for international students', 'course-catalog-system');
                $output .= '</div>';

                return $output . eol();
            }
            else
            {
                // Advanced Diploma & Tamhidi only

                $output  = "\n";
                $output .= '<div class="table-1">';
                //$output .= '<table class="table table-bordered table-striped ccs-program-table">' . "\n";
                $output .= '<table class="ccs-program-table" width="100%">' . "\n";
                $output .= '<thead>';
                $output .= '<tr>';
                $output .= '<th style="width: 5%;">&nbsp;</th>';
                $output .= '<th>' . __('Programme', 'course-catalog-system') . '</th>';
                $output .= '</tr>';
                $output .= '</thead>' . "\n";
                $output .= '<tbody>' . "\n";

                $count_local = 0;
                $program_count = 0;

                foreach ($faculties as $faculty)
                {
                    $row = 1;

                    foreach ($programs as $program)
                    {
                        if ($program->faculty_id == $faculty->faculty_id)
                        {
                            $program_count++;

                            $output .= '<tr>';
                            $output .= '<td style="text-align: center;">' . $program_count . '</td>';

                            $output .= '<td>';
                            if ($program->program_scope == 'L')
                            {
                                $output .= '<span style="color:red;">*</span>&nbsp;';
                                $count_local++;
                            }
                            if ( ! empty($program->program_code))
                            {
                                $output .= $program->program_code . ': ';
                            }

                            $output .= '<a href="' . get_site_url() . $ccs_program_details_page . '?' . $ccs_program_id_param . '=' . $program->program_id . '">';
                            $output .= $program->program_name;
                            $output .= '</a>';

                            $output .= '</td>';
                            $output .= '</tr>' . "\n";
                            $row++;
                        }
                    }
                }

                $output .= '</tbody>' . "\n";
                $output .= '</table>' . "\n";
                $output .= '</div>';
                $output .= '<br>';

                $output .= '<div class="ccs-text">';
                $output .= __('Programme marked (', 'course-catalog-system');
                $output .= '<span style="color:red;">*</span>';
                //$output .= __(') are available for Malaysian students only', 'course-catalog-system');
                $output .= __(') are not available for international students', 'course-catalog-system');
                $output .= '</div>';

                return $output . eol();

            }
        }
        else
        {
            return eol();
        }
    }
    else
    {
        return __('No result', 'course-catalog-system') . eol();
    }
}
add_shortcode('ccs_render_program_list', 'ccs_render_program_list');

/**
 * List programmes under particular faculty, grouped by level of studies
 */
function ccs_render_faculty_program_list($atts)
{
    // /api/wordpress/faculty_programs/{faculty}/{lang}

    if (defined('ICL_LANGUAGE_CODE'))
    {
        $lang = ICL_LANGUAGE_CODE;
    }
    else
    {
        if (function_exists('qtranxf_getLanguage'))
        {
            $lang = qtranxf_getLanguage();
        }
        else
        {
            $lang = 'en';
        }
    }

    // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
    // Each __() function must be __('Words to translate', 'course-catalog-system')
    load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

    $options = get_option(CCS_OPTION_NAME);
    $ccs_url = $options['ccs_url'];
    $ccs_faculty_id_param = $options['ccs_faculty_id_param'];
    $ccs_program_details_page = $options['ccs_program_details_page'];
    $ccs_program_id_param = $options['ccs_program_id_param'];
    $ccs_program_search_page = $options['ccs_program_search_page'];

    $fid = isset( $_GET[$ccs_faculty_id_param] ) ? ($_GET[$ccs_faculty_id_param] != '' ? $_GET[$ccs_faculty_id_param] : 'all') : 'all';

    $faculty_name = '';
    $output = '';

    if ($fid == 'all')
    {
    /*
        $remote_url = $options['ccs_url'] . '/api/wordpress/faculty_programs_count/' . $fid . '/' . $lang;
        $response = ccs_get_content_curl($remote_url);

        $json_data = $response['html'];
        $programs_count = json_decode($json_data);

        $current_studylevel = '';
        $current_faculty = '';
        $faculty_count = 0;

        $faculty_name = __('All Faculties', 'course-catalog-system');

        if (count($programs_count) > 0)
        {
            $remote_url = $ccs_url . '/api/wordpress/faculty_programs/' . $fid . '/' . $lang;
            $response = ccs_get_content_curl($remote_url);

            $json_data = $response['html'];
            $programs = json_decode($json_data);

            $count_local = 0;
            $cnt = 0;

            // Loop all studylevels
            foreach ($programs_count as $prg_cnt)
            {
                if ($prg_cnt->studylevel_id != $current_studylevel)
                {
                    if ($cnt > 0)
                    {
                        $output .= '</tbody>' . "\n";
                        $output .= '</table>' . "\n";
                        $output .= '</div>' . "\n";
                        $output .= '<br>';
                    }
                    $output .= '<h3>' . $prg_cnt->studylevel_name . '</h3>';
                    $current_studylevel = $prg_cnt->studylevel_id;

                    $output .= '<div class="table-1">';
                    $output .= '<table class="ccs-program-table" width="100%">' . "\n";
                    $output .= '<thead>';
                    $output .= '<tr>';
                    if ($prg_cnt->studylevel_id != '13' && $prg_cnt->studylevel_id != '14')
                    {
                        $output .= '<th style="width: 40%;">' . __('Faculty', 'course-catalog-system') . '</th>';
                    }
                    $output .= '<th>' . __('Programme', 'course-catalog-system') . '</th>';
                    $output .= '</tr>';
                    $output .= '</thead>' . "\n";
                    $output .= '<tbody>' . "\n";
                }

                if ($prg_cnt->faculty_name != $current_faculty)
                {
                    $faculty_count++;
                    $current_faculty = $prg_cnt->faculty_name;
                }

                if ($prg_cnt->program_count > 0)
                {
                    $row = 0;

                    $current_faculty = '';
                    $prog_count = 0;

                    $output .= '<tr>';
                    if ($row == 0)
                    {
                        if ($prg_cnt->studylevel_id != '13' && $prg_cnt->studylevel_id != '14')
                        {
                            $output .= '<td rowspan="' . $prg_cnt->program_count . '" style="background-color: #ffffff;">';
                            if ( ! empty($prg_cnt->faculty_name))
                            {
                                //$output .= '<strong>' . $prg_cnt->faculty_name . '</strong>' . '<br>';
                                $output .= $prg_cnt->faculty_name . '<br>';
                            }
                            $output .= '</td>';
                        }
                    }

                    // Loop all programs
                    foreach ($programs as $program)
                    {
                        $prog_count++;
                        if ($prog_count > $prg_cnt->program_count)
                        {
                            //break;
                        }

                        if ($program->faculty_id == $prg_cnt->faculty_id && $program->studylevel_id == $prg_cnt->studylevel_id)
                        {
                            if ( ! empty($current_faculty) && $current_faculty != $program->faculty_id)
                            {
                                break;
                            }

                            $output .= '<td>';

                            if ($program->program_scope == 'L')
                            {
                                $output .= '<span style="color:red;">*</span>&nbsp;';
                                $count_local++;
                            }

                            $output .= '<a href="' . get_site_url() . $ccs_program_details_page . '?' . $ccs_program_id_param . '=' . $program->program_id . '">';
                            if ( ! empty($program->program_code))
                            {
                                $output .= $program->program_code . ': ';
                            }
                            $output .= $program->program_name;
                            $output .= '</a>';

                            $output .= '</td>';
                            $output .= '</tr>' . "\n";

                            $row++;
                            $current_faculty = $program->faculty_id;
                        }
                    }
                }
                $cnt++;
            }

            if ($cnt > 0)
            {
                $output .= '</tbody>' . "\n";
                $output .= '</table>';
                $output .= '</div>' . "\n";
                $output .= '<br>';
            }

            $output .= '<br>';
            $output .= '<div class="ccs-text">';
            $output .= __('Programme marked (', 'course-catalog-system');
            $output .= '<span style="color:red;">*</span>';
            $output .= __(') are not available for international students', 'course-catalog-system');
            $output .= '</div>';
            $output .= '<br>';

            $output = $output . do_shortcode('[button type="default" shape="default" icon="fa-search" id="btn_search" link="' . get_site_url() . $ccs_program_search_page . '"]' . __('Search Program', 'course-catalog-system') . '[/button]');
        }
        else
        {
            $output .= __('No Programme found', 'course-catalog-system');
        }
    */

       $output .= __('No Programme found');

    }
    else
    {
        $remote_url = $options['ccs_url'] . '/api/wordpress/faculty_programs_count/' . $fid . '/' . $lang;
        $response = ccs_get_content_curl($remote_url);

        $json_data = $response['html'];
        $programs_count = json_decode($json_data);

        $current_faculty = '';
        $faculty_count = 0;

        if (count($programs_count) > 0)
        {
            $remote_url = $ccs_url . '/api/wordpress/faculty_programs/' . $fid . '/' . $lang;
            $response = ccs_get_content_curl($remote_url);

            $json_data = $response['html'];
            $programs = json_decode($json_data);

            $output .= '<div class="table-1">';
            $output .= '<table class="ccs-program-table" width="100%">' . "\n";
            $output .= '<thead>';
            $output .= '<tr>';
            $output .= '<th style="width: 5%;">&nbsp;</th>';
            $output .= '<th>' . __('Level of Study', 'course-catalog-system') . '</th>';
            $output .= '<th>' . __('Programme', 'course-catalog-system') . '</th>';
            $output .= '<th>' . __('Program Option', 'course-catalog-system') . '</th>';
            $output .= '</tr>';
            $output .= '</thead>' . "\n";
            $output .= '<tbody>' . "\n";

            $count_local = 0;
            $idx = 1;

            // Loop all studylevels
            foreach ($programs_count as $prg_cnt)
            {
                if ($prg_cnt->faculty_name != $current_faculty)
                {
                    $faculty_count++;
                    $current_faculty = $prg_cnt->faculty_name;

                    if (empty($faculty_name))
                    {
                        $faculty_name = $prg_cnt->faculty_name;
                    }
                }

                if ($prg_cnt->program_count > 0)
                {
                    $row = 0;

                    $current_faculty = '';
                    $prog_count = 0;

                    $output .= '<tr>';

                    if ($row == 0)
                    {
                        $output .= '<td style="text-align: center;">' . $idx . '</td>';

                        $output .= '<td rowspan="' . $prg_cnt->program_count . '" style="background-color: #ffffff;">';
                        if ($fid == 'all')
                        {
                            if ( ! empty($prg_cnt->faculty_name))
                            {
                                $output .= $prg_cnt->faculty_name;
                            }
                        }
                        else
                        {
                            $output .= $prg_cnt->studylevel_name;
                        }
                        $output .= '</td>';
                    }

                    // Loop all programs
                    foreach ($programs as $program)
                    {
                        $prog_count++;
                        if ($prog_count > $prg_cnt->program_count)
                        {
                            //break;
                        }

                        if ($program->faculty_id == $prg_cnt->faculty_id && $program->studylevel_id == $prg_cnt->studylevel_id)
                        {
                            if ( ! empty($current_faculty) && $current_faculty != $program->faculty_id)
                            {
                                break;
                            }

                            if ($row > 0)
                            {
                                $output .= '<td style="text-align: center;">' . $idx . '</td>';
                            }

                            $output .= '<td>';

                            if ($program->program_scope == 'L')
                            {
                                $output .= '<span style="color:red;">*</span>&nbsp;';
                                $count_local++;
                            }

                            $output .= '<a href="' . get_site_url() . $ccs_program_details_page . '?' . $ccs_program_id_param . '=' . $program->program_id . '">';
                            if ( ! empty($program->program_code))
                            {
                                $output .= $program->program_code . ': ';
                            }
                            $output .= $program->program_name;
                            $output .= '</a>';

                            $output .= '</td>';

                            $output .= '<td>';
                            if ($program->program_research_coursework == '10')
                            {
                                $output .= __('By Research', 'course-catalog-system');
                            }
                            else if ($program->program_research_coursework == '1000')
                            {
                                $output .= __('By Coursework', 'course-catalog-system');
                            }
                            else if ($program->program_research_coursework == '1010')
                            {
                                $output .= __('By Mixed Mode', 'course-catalog-system');
                            }
                            else
                            {
                                $output .= '&nbsp;';
                            }
                            $output .= '</td>';
                            $output .= '</tr>' . "\n";

                            $row++;
                            $idx++;
                            $current_faculty = $program->faculty_id;
                        }
                    }
                }
            }

            $output .= '</tbody>' . "\n";
            $output .= '</table>' . "\n";
            $output .= '</div>' . "\n";

            $output .= '<br>';
            $output .= '<div class="ccs-text">';
            $output .= __('Programme marked (', 'course-catalog-system');
            $output .= '<span style="color:red;">*</span>';
            $output .= __(') are not available for international students', 'course-catalog-system');
            $output .= '</div>';
            $output .= '<br>';

            $output = $output . do_shortcode('[button type="default" shape="default" icon="fa-search" id="btn_search" link="' . get_site_url() . $ccs_program_search_page . '"]' . __('Search Program', 'course-catalog-system') . '[/button]');
        }
        else
        {
            $output .= __('No Programme found');
            $remote_url = $ccs_url . '/api/wordpress/faculty/' . $fid . '/' . $lang;
            $response = ccs_get_content_curl($remote_url);

            $json_data = $response['html'];
            $program = json_decode($json_data);

            $faculty_name = $program->faculty_name;
        }
    }

    $output .= '<script type="text/javascript">';
    if ($faculty_count <= 2)
    {
        $output .= "var page_title = jQuery('.fusion-page-title-captions > .entry-title');";
        $output .= "page_title.html('" . $faculty_name . "');" ;
        $output .= "page_title.css('text-transform', 'uppercase');";
    }
    $output .= '</script>';

    $output .= "\n";

    return $output . eol();
}
add_shortcode('ccs_render_faculty_program_list', 'ccs_render_faculty_program_list');

function ccs_render_program_details()
{
    if (defined('ICL_LANGUAGE_CODE'))
    {
        $lang = ICL_LANGUAGE_CODE;
    }
    else
    {
        if (function_exists('qtranxf_getLanguage'))
        {
            $lang = qtranxf_getLanguage();
        }
        else
        {
            $lang = 'en';
        }
    }

    // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
    // Each __() function must be __('Words to translate', 'course-catalog-system')
    load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

    $options = get_option(CCS_OPTION_NAME);
    $ccs_url = $options['ccs_url'];
    $ccs_program_id_param = $options['ccs_program_id_param'];
    $ccs_tag_background_color = $options['ccs_tag_background_color'];
    if (empty($ccs_tag_background_color)) $ccs_tag_background_color = '#a0ce4e';
    $ccs_tag_color = $options['ccs_tag_color'];
    if (empty($ccs_tag_color)) $ccs_tag_color = '#ffffff';

    $pid = isset( $_GET[$ccs_program_id_param] ) ? $_GET[$ccs_program_id_param] : '';

    $output = '';

    if ( ! empty($pid))
    {
        $remote_url = $ccs_url . '/api/wordpress/details/' . $pid . '/' . $lang;
        $response = ccs_get_content_curl($remote_url);

        $json_data = $response['html'];
        $details = json_decode($json_data);		// Program details

        if (count($details) > 0)
        {
            $row = $details[0];

            $content = do_shortcode('[tagline_box highlightposition="top" margin_bottom="20px"]<h2>' . $row->program_name . '</h2>[/tagline_box]');

            $output .= $content;

            $content  = '<h3>' . __('PROGRAM DETAILS', 'course-catalog-system') . '</h3>';
            $content .= '<strong>' . __('Medium of instructions: ', 'course-catalog-system') . '</strong>';

            $i = 0;
            $program_mediums = $row->program_mediums;
            foreach ($program_mediums as $medium)
            {
                if ($i > 0)
                {
                    $content .= __('and', 'course-catalog-system') . ' ';
                }
                $content .= $medium . ' ';
                if ($lang == 'en')
                {
                    $content .= __('Language', 'course-catalog-system') . ' ';
                }
                $i++;
            }

            $content .= '<br>';
            if ( ! empty($row->program_credithour) && $row->program_credithour > 0)
            {
                $content .= '<strong>' . __('Credit hours: ', 'course-catalog-system') . '</strong>' . $row->program_credithour . '<br>';
            }

            if ( ! empty($row->program_duration_year) && $row->program_duration_year > 0 OR
                 ! empty($row->program_duration_semester) && $row->program_duration_semester > 0)
            {
                $content .= '<strong>' . __('Programme length: ', 'course-catalog-system') . '</strong>';

                if ( ! empty($row->program_duration_year) && $row->program_duration_year > 0)
                {
                    $content .= $row->program_duration_year . ' ';

                    if ($row->program_duration_year > 1 && $lang == 'en')
                    {
                        $content .= __('years', 'course-catalog-system') . ' ';
                    }
                    else
                    {
                        $content .= __('year', 'course-catalog-system') . ' ';
                    }

                }

                if ( ! empty($row->program_duration_year) && $row->program_duration_year > 0)
                {
                    $content .= '(' . $row->program_duration_semester . ' ';

                    if ($row->program_duration_semester > 1 && $lang == 'en')
                    {
                        $content .= __('semesters', 'course-catalog-system') . ') ';
                    }
                    else
                    {
                        $content .= __('semester', 'course-catalog-system') . ') ';
                    }
                }
                else
                {
                    $content .= $row->program_duration_semester . ' ';

                    if ($row->program_duration_semester > 1 && $lang == 'en')
                    {
                        $content .= __('semesters', 'course-catalog-system');
                    }
                    else
                    {
                        $content .= __('semester', 'course-catalog-system');
                    }
                }

                if ($row->program_type == 'F')
                {
                    $content .= __('of full-time studies', 'course-catalog-system');
                }
                else if ($row->program_type == 'P')
                {
                    $content .= __('of part-time studies', 'course-catalog-system');
                }
                else if ($row->program_type == 'B')
                {
                    $content .= __('of full-time or part-time studies', 'course-catalog-system');
                }
            }

            if ($row->program_research_thesis == '1' OR $row->program_coursework == '1')
            {
                $content .= '<strong>' . __('Programme Option: ', 'course-catalog-system') . '</strong>';
                if ($row->program_research_thesis == '1')
                {
                    if ($row->program_coursework == '1')
                    {
                        $content .= __('Mixed Mode', 'course-catalog-system') . '<br>';
                    }
                    else
                    {
                        $content .= __('Research', 'course-catalog-system') . '<br>';
                    }
                }else
                {
                    $content .= __('Coursework', 'course-catalog-system') . '<br>';
                }
            }

            if ( ! empty($row->program_description) ||  ! empty($row->program_careerprospect))
            {
                $content .= '<br><br>';
            }

            if ( ! empty($row->program_description))
            {
                $content .= $row->program_description;
            }

            if ( ! empty($row->program_careerprospect))
            {
                $content .= '<h3>' . __('CAREER PROSPECTS', 'course-catalog-system') . '</h3>';
                $content .= $row->program_careerprospect;
            }

            if ( ! empty($row->program_tags))
            {
                $tags = explode(',', $row->program_tags);

                if (count($tags) > 0)
                {
                    $content .= '<br><p>' . __('Tags: ');

                    foreach ($tags as $tag)
                    {
                        $content .= '<span class="fusion-highlight light highlight1" style="background-color:' . $ccs_tag_background_color . ';">' .
                                    '<span style="color: ' . $ccs_tag_color . ';">' . $tag . '</span>' .
                                    '</span>&nbsp;';
                    }

                    $content .= '</p>';
                }
            }

            $content = do_shortcode('[tagline_box highlightposition="top" margin_bottom="20px"]' .
                        $content .
                        '[/tagline_box]');

            if ($row->program_scope == 'L')
            {
                $content .= '<span style="color:red;">*</span> <em>' . __('This programme is not available for international students', 'course-catalog-system') . '</em>';
                $content .= '<br><br>';
            }

            $output .= $content;

            $output .= '<script type="text/javascript">';
            $output .= "var page_title = jQuery('.fusion-page-title-captions > .entry-title');";
            $output .= "page_title.html('" . $row->studylevel_name . "');" ;
            $output .= "page_title.css('text-transform', 'uppercase');";
            $output .= '</script>';

        }
    }

    return $output . eol();
}
add_shortcode('ccs_render_program_details', 'ccs_render_program_details');

/*
function ccs_render_program_requirements()
{
    if (defined('ICL_LANGUAGE_CODE'))
    {
        $lang = ICL_LANGUAGE_CODE;
    }
    else
    {
        if (function_exists('qtranxf_getLanguage'))
        {
            $lang = qtranxf_getLanguage();
        }
        else
        {
            $lang = 'en';
        }
    }

    // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
    // Each __() function must be __('Words to translate', 'course-catalog-system')
    load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

    $options = get_option(CCS_OPTION_NAME);
    $ccs_url = $options['ccs_url'];
    $ccs_program_id_param = $options['ccs_program_id_param'];

    $pid = isset( $_GET[$ccs_program_id_param] ) ? $_GET[$ccs_program_id_param] : '';

    $output = '';

    if ( ! empty($pid))
    {
        $remote_url = $ccs_url . '/api/wordpress/program_requirements/' . $pid . '/' . $lang;
        $response = ccs_get_content_curl($remote_url);

        $json_data = $response['html'];
        $requirements = json_decode($json_data);		// Program details

        if (count($requirements) > 0)
        {
            $output .= '[fusion_tabs design="classic" layout="horizontal" justified="yes" class="ccs-tabs"]';

            $contents = '';
            $tab_title = '';

            $requirement_tabs = array('L', 'I');

            foreach ($requirement_tabs as $tab)
            {
                $tab_title = ($tab == 'L' ? __('Local Students', 'course-catalog-system') : __('International Students', 'course-catalog-system'));

                if (isset($requirements->$tab))
                {
                    $content = $requirements->$tab;

                    $contents .= '[fusion_tab title="' . $tab_title . '" icon="' . ($tab == 'L' ? 'fa-user' : 'fa-file-o') . '"]';
                    $contents .= do_shortcode($content);
                    $contents .= '[/fusion_tab]';
                }
                //else
                //{
                //    $contents .= '[fusion_tab title="' . $tab_title . '" icon="' . ($tab == 'L' ? 'fa-user' : 'fa-file-o') . '"]';
                //    $contents .= '&nbsp;';
                //    $contents .= '[/fusion_tab]';
                //}
            }

            $output .= $contents . '[/fusion_tabs]';

            $output = do_shortcode($output);
        }
    }

    return $output . eol();
}
add_shortcode('ccs_render_program_requirements', 'ccs_render_program_requirements');
*/
function ccs_render_program_requirements()
{
    if (defined('ICL_LANGUAGE_CODE'))
    {
        $lang = ICL_LANGUAGE_CODE;
    }
    else
    {
        if (function_exists('qtranxf_getLanguage'))
        {
            $lang = qtranxf_getLanguage();
        }
        else
        {
            $lang = 'en';
        }
    }

    // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
    // Each __() function must be __('Words to translate', 'course-catalog-system')
    load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

    $options = get_option(CCS_OPTION_NAME);
    $ccs_url = $options['ccs_url'];
    $ccs_program_id_param = $options['ccs_program_id_param'];

    $pid = isset( $_GET[$ccs_program_id_param] ) ? $_GET[$ccs_program_id_param] : '';

    $output = '';

    if ( ! empty($pid))
    {
        $remote_url = $ccs_url . '/api/wordpress/program_requirements/' . $pid . '/' . $lang;
        $response = ccs_get_content_curl($remote_url);

        $json_data = $response['html'];
        $requirements = json_decode($json_data);		// Program details

        if (count($requirements) > 0)
        {
            $output .= '[fusion_tabs design="classic" layout="horizontal" justified="yes" class="ccs-tabs"]';

            $tab_title = '';

            foreach ($requirements as $scope => $requirement_list)
            {
                $tab_title = ($scope == 'L' ? __('Local Students', 'course-catalog-system') : __('International Students', 'course-catalog-system'));
                $output .= '[fusion_tab title="' . $tab_title . '" icon="' . ($scope == 'L' ? 'fa-user' : 'fa-file-o') . '"]';
                $contents = '';

                if (count($requirement_list) > 0)
                {
                    $contents .= '[accordian divider_line="no"]';
                    $specific_req = false;

                    foreach ($requirement_list as $requirement)
                    {
                        $contents  .= '[toggle title="' . $requirement->requirement_type_name . '" open="no"]';
                        if ( ! isset($requirement->rows))
                        {
                            $contents .= do_shortcode($requirement->requirement_description);
                        }
                        else
                        {
                            if ( ! empty($requirement->rows[0]->admission_type_name))
                            {
                                $tabcontent = '[fusion_tabs design="classic" layout="vertical"]';
                                foreach ($requirement->rows as $row)
                                {
                                    $tabcontent .= '[fusion_tab title="' . $row->admission_type_name . '"]' . do_shortcode($row->requirement_description) . '[/fusion_tab]';
                                }
                                $tabcontent .= '[/fusion_tabs]';

                                $contents .= do_shortcode($tabcontent);
                            }
                            else
                            {
                                foreach ($requirement->rows as $row)
                                {
                                    $contents .= do_shortcode($row->requirement_description);
                                }
                            }
                        }
                        $contents .= '[/toggle]';
                    }

                    $contents .= '[/accordian]';

                    $output .= do_shortcode($contents);
                }

                $output .= '[/fusion_tab]';
            }

            $output .= '[/fusion_tabs]';

            $output = do_shortcode($output);

            $output .= '<script type="text/javascript">';
            $output .= "var border_color = jQuery('.fusion-tabs > .nav').css('border-top-color');";
            $output .= "jQuery('.ccs-tabs .toggle-content > p').css('margin-bottom', '0px');";
            $output .= "jQuery('.ccs-tabs .fusion-tabs').css('margin-bottom', '0px');";
            $output .= "jQuery('.ccs-tabs .tab-content > .tab-pane').css('border-right-width', '1px');";
            $output .= "jQuery('.ccs-tabs .tab-content > .tab-pane').css('border-right-style', 'solid');";
            $output .= "jQuery('.ccs-tabs .tab-content > .tab-pane').css('border-right-color', border_color);";
            $output .= "jQuery('.ccs-tabs .tab-content > .tab-pane').css('border-bottom-width', '1px');";
            $output .= "jQuery('.ccs-tabs .tab-content > .tab-pane').css('border-bottom-style', 'solid');";
            $output .= "jQuery('.ccs-tabs .tab-content > .tab-pane').css('border-bottom-color', border_color);";
            $output .= '</script>';

        }
    }

    return $output . eol();
}
add_shortcode('ccs_render_program_requirements', 'ccs_render_program_requirements');

/*
function ccs_render_program_common_requirements()
{
    if (defined('ICL_LANGUAGE_CODE'))
    {
        $lang = ICL_LANGUAGE_CODE;
    }
    else
    {
        if (function_exists('qtranxf_getLanguage'))
        {
            $lang = qtranxf_getLanguage();
        }
        else
        {
            $lang = 'en';
        }
    }

    // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
    // Each __() function must be __('Words to translate', 'course-catalog-system')
    load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

    $options = get_option(CCS_OPTION_NAME);
    $ccs_url = $options['ccs_url'];
    $ccs_program_id_param = $options['ccs_program_id_param'];

    $pid = isset( $_GET[$ccs_program_id_param] ) ? $_GET[$ccs_program_id_param] : '';

    $output = '';

    if ( ! empty($pid))
    {
        $remote_url = $ccs_url . '/api/wordpress/program_common_requirements/' . $pid . '/' . $lang;
        $response = ccs_get_content_curl($remote_url);

        $json_data = $response['html'];
        $requirements = json_decode($json_data);		// Program details

        if (count($requirements) > 0)
        {
            $output .= '[fusion_tabs design="classic" layout="horizontal" justified="yes" class="ccs-tabs-common"]';

//            if ($requirements[0]->studylevel_id != '11')
//            {
//                $tab_title = __('Common Requirements', 'course-catalog-system');
//            }
//            else
//            {
//                $tab_title = __('Requirements', 'course-catalog-system');
//            }

            $tab_title = __('Admission Requirements', 'course-catalog-system');

            $output .= '[fusion_tab title="' . $tab_title . '" icon="' . 'fa-list' . '"]';

            foreach ($requirements as $requirement)
            {
                $output .= do_shortcode($requirement->requirement_description);
            }

            $output .= '[/fusion_tab]';
            $output .= '[/fusion_tabs]';

            $output = do_shortcode($output);

            $output .= '<script type="text/javascript">';
//            $output .= "var border_color = jQuery('.fusion-tabs > .nav').css('border-top-color');";
//            $output .= "jQuery('.ccs-tabs .toggle-content > p').css('margin-bottom', '0px');";
//            $output .= "jQuery('.ccs-tabs .fusion-tabs').css('margin-bottom', '0px');";
            $output .= "jQuery('.ccs-tabs-common > .tab-content > .tab-pane > p:last-of-type').css('margin-bottom', '10px');";
//            $output .= "jQuery('.ccs-tabs .tab-content > .tab-pane').css('border-right-style', 'solid');";
//            $output .= "jQuery('.ccs-tabs .tab-content > .tab-pane').css('border-right-color', border_color);";
//            $output .= "jQuery('.ccs-tabs .tab-content > .tab-pane').css('border-bottom-width', '1px');";
//            $output .= "jQuery('.ccs-tabs .tab-content > .tab-pane').css('border-bottom-style', 'solid');";
//            $output .= "jQuery('.ccs-tabs .tab-content > .tab-pane').css('border-bottom-color', border_color);";
            $output .= '</script>';
        }
    }

    return $output . eol();
}
add_shortcode('ccs_render_program_common_requirements', 'ccs_render_program_common_requirements');
*/

function ccs_render_program_common_requirements()
{
    if (defined('ICL_LANGUAGE_CODE'))
    {
        $lang = ICL_LANGUAGE_CODE;
    }
    else
    {
        if (function_exists('qtranxf_getLanguage'))
        {
            $lang = qtranxf_getLanguage();
        }
        else
        {
            $lang = 'en';
        }
    }

    // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
    // Each __() function must be __('Words to translate', 'course-catalog-system')
    load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

    $options = get_option(CCS_OPTION_NAME);
    $ccs_url = $options['ccs_url'];
    $ccs_program_id_param = $options['ccs_program_id_param'];

    $pid = isset( $_GET[$ccs_program_id_param] ) ? $_GET[$ccs_program_id_param] : '';

    $output = '';

    if ( ! empty($pid))
    {
        $remote_url = $ccs_url . '/api/wordpress/program_common_requirements/' . $pid . '/' . $lang;
        $response = ccs_get_content_curl($remote_url);

        $json_data = $response['html'];
        $requirements = json_decode($json_data);		// Program details

        if (count($requirements) > 0)
        {
            $output .= '[fusion_tabs design="classic" layout="horizontal" justified="yes" class="ccs-tabs-common"]';
            $tab_title = __('Admission Requirements', 'course-catalog-system');
            $output .= '[fusion_tab title="' . $tab_title . '" icon="' . 'fa-list' . '"]';

            $scopes = array('B');

            foreach ($scopes as $scope)
            {
                if (isset($requirements->$scope))
                {
                    $output .= $requirements->$scope;
                }
            }

            $output .= '[/fusion_tab]';
            $output .= '[/fusion_tabs]';

            $output = do_shortcode($output);

            $output .= '<script type="text/javascript">';
            $output .= "jQuery('.ccs-tabs-common > .tab-content > .tab-pane > p:last-of-type').css('margin-bottom', '10px');";
            $output .= '</script>';
        }
    }

    return $output . eol();
}
add_shortcode('ccs_render_program_common_requirements', 'ccs_render_program_common_requirements');

function ccs_render_program_contact_us()
{
    if (defined('ICL_LANGUAGE_CODE'))
    {
        $lang = ICL_LANGUAGE_CODE;
    }
    else
    {
        if (function_exists('qtranxf_getLanguage'))
        {
            $lang = qtranxf_getLanguage();
        }
        else
        {
            $lang = 'en';
        }
    }

    // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
    // Each __() function must be __('Words to translate', 'course-catalog-system')
    load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

    $options = get_option(CCS_OPTION_NAME);
    $ccs_url = $options['ccs_url'];
    $ccs_program_id_param = $options['ccs_program_id_param'];

    $pid = isset( $_GET[$ccs_program_id_param] ) ? $_GET[$ccs_program_id_param] : '';

    $output = '';

    if ( ! empty($pid))
    {
        $remote_url = $ccs_url . '/api/wordpress/program_contact_us/' . $pid . '/' . $lang;
        $response = ccs_get_content_curl($remote_url);

        $json_data = $response['html'];
        $requirements = json_decode($json_data);		// Program details

        if (count($requirements) > 0)
        {
            $output .= '[tagline_box highlightposition="top" margin_bottom="20px" title="' . __('Contact Us', 'course-catalog-system') . '"]';

            $scopes = array('L', 'I');

            $contact_cnt = 0;

            foreach ($scopes as $scope)
            {
                if (isset($requirements->$scope))
                {
                    $contact_cnt++;

                    if ($contact_cnt > 1)
                    {
                        $output .= '<br>';
                    }

                    $output .= '<h3>' . ($scope == 'L' ? __('Local Students', 'course-catalog-system') : __('International Students', 'course-catalog-system')) . '</h3>';
                    $output .= $requirements->$scope;
                }

            }

            $output .= '[/tagline_box]';

            $output = do_shortcode($output);
        }
    }

    return $output . eol();
}
add_shortcode('ccs_render_program_contact_us', 'ccs_render_program_contact_us');

function ccs_render_program_whats_next()
{
     if (defined('ICL_LANGUAGE_CODE'))
    {
        $lang = ICL_LANGUAGE_CODE;
    }
    else
    {
        if (function_exists('qtranxf_getLanguage'))
        {
            $lang = qtranxf_getLanguage();
        }
        else
        {
            $lang = 'en';
        }
    }

    // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
    // Each __() function must be __('Words to translate', 'course-catalog-system')
    load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

    $options = get_option(CCS_OPTION_NAME);
    $ccs_url = $options['ccs_url'];
    $ccs_program_id_param = $options['ccs_program_id_param'];

    $pid = isset( $_GET[$ccs_program_id_param] ) ? $_GET[$ccs_program_id_param] : '';

    $output = '';

    if ( ! empty($pid))
    {
        $remote_url = $ccs_url . '/api/wordpress/program_whats_next/' . $pid . '/' . $lang;
        $response = ccs_get_content_curl($remote_url);

        $json_data = $response['html'];
        $requirements = json_decode($json_data);		// Program details

        if (count($requirements) > 0)
        {
            $output .= '[tagline_box highlightposition="top" margin_bottom="20px" title="' . __('What To Do Next', 'course-catalog-system') . '"]';

            $scopes = array('L', 'I');

            $contact_cnt = 0;

            foreach ($scopes as $scope)
            {
                if (isset($requirements->$scope))
                {
                    $contact_cnt++;

                    if ($contact_cnt > 1)
                    {
                        $output .= '<br>';
                    }

                    $output .= '<h3>' . ($scope == 'L' ? __('Local Students', 'course-catalog-system') : __('International Students', 'course-catalog-system')) . '</h3>';
                    $output .= $requirements->$scope;
                }
            }

            $output .= '[/tagline_box]';

            $output = do_shortcode($output);
        }
    }

    return $output . eol();
}
add_shortcode('ccs_render_program_whats_next', 'ccs_render_program_whats_next');

/**
 * Get program testimonial
 */
function ccs_render_testimonial()
{
    if (defined('ICL_LANGUAGE_CODE'))
    {
        $lang = ICL_LANGUAGE_CODE;
    }
    else
    {
        if (function_exists('qtranxf_getLanguage'))
        {
            $lang = qtranxf_getLanguage();
        }
        else
        {
            $lang = 'en';
        }
    }

    // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
    // Each __() function must be __('Words to translate', 'course-catalog-system')
    load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

    $options = get_option(CCS_OPTION_NAME);
    $ccs_url = $options['ccs_url'];
    $ccs_program_id_param = $options['ccs_program_id_param'];

    $pid = isset( $_GET[$ccs_program_id_param] ) ? $_GET[$ccs_program_id_param] : '';

    $output = '';

    if ( ! empty($pid))
    {
        $remote_url = $ccs_url . '/api/wordpress/testimonial/' . $pid . '/' . $lang;
        $response = ccs_get_content_curl($remote_url);

        $json_data = $response['html'];
        $testimonials = json_decode($json_data);

        $testimonial_count = 0;

        if (count($testimonials) > 0)
        {
            if (count($testimonials) == 1)
            {
                $output .= '[tagline_box highlightposition="top" margin_bottom="20px" title="' . __('Testimonial', 'course-catalog-system') . '" class="ccs-testimonial"]';
            }
            else
            {
                $output .= '[tagline_box highlightposition="top" margin_bottom="20px" title="' . __('Testimonials', 'course-catalog-system') . '" class="ccs-testimonial"]';
            }

            foreach ($testimonials as $testimonial)
            {
                if ($testimonial_count > 1)
                {
                    $output .= '<hr>';
                }
                $output .= '<img src="' . $testimonial->photo_url . '" alt="">';
                $output .= '<img src="' . plugins_url('images/quote.png', __FILE__) . '" alt="">' . '<br>';

                if ( ! empty($testimonial->testimonial_quote))
                {
                    $output .= '<span class="ccs-testimonial-quote">' . $testimonial->testimonial_quote . '</span>';
                }
                $output .= '[person name="' . $testimonial->testimonial_name . '" title="(' . $testimonial->testimonial_position . ')"][/person]';

                if (count($testimonial->education) > 0)
                {
                    $output .= '<span class="ccs-education-title">' . __('Education:', 'course-catalog-system') . $testimonial->testimonial_education . '</h4>';
                    $output .= '<ul class="ccs-education-list">';

                    foreach ($testimonial->education as $education)
                    {
                        if ($education->is_usim == '1')
                        {
                            $output .= '<li class="ccs-education-usim">' . $education->testimonial_education . '</li>';
                        }
                        else
                        {
                            $output .= '<li>' . $education->testimonial_education . '</li>';
                        }
                    }
                    $output .= '</ul>';
                }

                $testimonial_count++;
            }

            $output .= '[/tagline_box]';

            return do_shortcode($output) . eol();
        }
    }

    return eol();
}
add_shortcode('ccs_render_testimonial', 'ccs_render_testimonial');

function ccs_render_search_program()
{
    if (defined('ICL_LANGUAGE_CODE'))
    {
        $lang = ICL_LANGUAGE_CODE;
    }
    else
    {
        if (function_exists('qtranxf_getLanguage'))
        {
            $lang = qtranxf_getLanguage();
        }
        else
        {
            $lang = 'en';
        }
    }

    // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
    // Each __() function must be __('Words to translate', 'course-catalog-system')
    load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

    $options = get_option(CCS_OPTION_NAME);
    $ccs_url = $options['ccs_url'];
    $ccs_program_details_page = $options['ccs_program_details_page'];
    $ccs_program_id_param = $options['ccs_program_id_param'];
    $ccs_program_search_page = $options['ccs_program_search_page'];

    if ( ! isset($_GET['query']))
    {
        if ( ! isset($_POST['search']))
        {
//            $search_form = file_get_contents(CCS_SEARCH_FORM);
//
//            if ($search_form === FALSE)
//            {
//                $search_form = '';
//            }

            // Get faculty list
            $remote_url = $ccs_url . '/api/wordpress/faculties/' . $lang;
            $response = ccs_get_content_curl($remote_url);

            $json_data = $response['html'];
            $faculties = json_decode($json_data);

            $faculty_list = '';
            foreach ($faculties as $faculty)
            {
                $faculty_list .= '<option value="' . $faculty->faculty_id .  '">' . $faculty->faculty_name . '</option>';
            }

            // Get studylevel list
            $remote_url = $ccs_url . '/api/wordpress/studylevels/' . $lang;
            $response = ccs_get_content_curl($remote_url);

            $json_data = $response['html'];
            $studylevels = json_decode($json_data);

            $studylevel_list = '';
            foreach ($studylevels as $studylevel)
            {
                $studylevel_list .= '<option value="' . $studylevel->studylevel_id .  '">' . $studylevel->studylevel_name . '</option>';
            }

            $remote_url = $ccs_url . '/api/wordpress/search_config';
            $response = ccs_get_content_curl($remote_url);

            $json_data = $response['html'];
            $search_fields = json_decode($json_data);

            // -- Search form init start

            $search_form  = '<form method="post" id="ccs_search_form" name="ccs_search_form" class="ccs-form">';

            foreach ($search_fields as $field)
            {
                if ($field->name == 'program_code')
                {

                    $search_form .= '<div class="form-group clearfix">';
                    $search_form .= '<div class="col-xs-3 col-xs-offset-0 col-md-2 col-md-offset-1 program_code">';
                    $search_form .= '' . __('Programme Code', 'course-catalog-system') . '';
                    $search_form .= '</div>';
                    $search_form .= '<div class="col-xs-3 col-md-2">';
                    $search_form .= '<select id="program_code_filter" name="program_code_filter" style="width: 100%;">';
                    $search_form .= '<option value="ct">' . __('Contains', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="eq">' . __('Equals to', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="ne">' . __('Not equal to', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="sw">' . __('Starts with', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="ew">' . __('Ends with', 'course-catalog-system') . '</option>';
                    $search_form .= '</select>';
                    $search_form .= '</div>';
                    $search_form .= '<div class="col-xs-6 col-md-2">';
                    $search_form .= '<input type="text" id="program_code" name="program_code">';
                    $search_form .= '</div>';
                    $search_form .= '<div class="hidden-sm col-md-5">&nbsp;</div>';
                    $search_form .= '</div>';

                }
                else if ($field->name == 'program_name')
                {

                    $search_form .= '<div class="form-group clearfix">';
                    $search_form .= '<div class="col-xs-3 col-xs-offset-0 col-md-2 col-md-offset-1 program_name">';
                    $search_form .= '' . __('Programme Name', 'course-catalog-system') . '';
                    $search_form .= '</div>';
                    $search_form .= '<div class="col-xs-3 col-md-2">';
                    $search_form .= '<select id="program_name_filter" name="program_name_filter" style="width: 100%;">';
                    $search_form .= '<option value="ct">' . __('Contains', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="eq">' . __('Equals to', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="ne">' . __('Not equal to', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="sw">' . __('Starts with', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="ew">' . __('Ends with', 'course-catalog-system') . '</option>';
                    $search_form .= '</select>';
                    $search_form .= '</div>';
                    $search_form .= '<div class="col-xs-6 col-md-6">';
                    $search_form .= '<input type="text" id="program_name" name="program_name">';
                    $search_form .= '</div>';
                    $search_form .= '</div>';

                }
                else if ($field->name == 'faculty_id')
                {

                    $search_form .= '<div class="form-group clearfix">';
                    $search_form .= '<div class="col-xs-3 col-xs-offset-0 col-md-2 col-md-offset-1 faculty_id">';
                    $search_form .= '' . __('Faculty', 'course-catalog-system') . '';
                    $search_form .= '</div>';
                    $search_form .= '<div class="col-xs-3 col-md-2">';
                    $search_form .= '<select id="faculty_id_filter" name="faculty_id_filter" style="width: 100%;">';
                    $search_form .= '<option value="eq">' . __('Equals to', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="ne">' . __('Not equal to', 'course-catalog-system') . '</option>';
                    $search_form .= '</select>';
                    $search_form .= '</div>';
                    $search_form .= '<div class="col-xs-6 col-md-6">';
                    $search_form .= '<select id="faculty_id" name="faculty_id">';
                    $search_form .= '<option value="">&nbsp;</option>';
                    $search_form .= $faculty_list;
                    $search_form .= '</select>';
                    $search_form .= '</div>';
                    $search_form .= '</div>';

                }
                else if ($field->name == 'studylevel_id')
                {

                    $search_form .= '<div class="form-group clearfix">';
                    $search_form .= '<div class="col-xs-3 col-xs-offset-0 col-md-2 col-md-offset-1 studylevel_id">';
                    $search_form .= '' . __('Level of Study', 'course-catalog-system') . '';
                    $search_form .= '</div>';
                    $search_form .= '<div class="col-xs-3 col-md-2">';
                    $search_form .= '<select id="studylevel_id_filter" name="studylevel_id_filter" style="width: 100%;">';
                    $search_form .= '<option value="eq">' . __('Equals to', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="ne">' . __('Not equal to', 'course-catalog-system') . '</option>';
                    $search_form .= '</select>';
                    $search_form .= '</div>';
                    $search_form .= '<div class="col-xs-6 col-md-3">';
                    $search_form .= '<select id="studylevel_id" name="studylevel_id">';
                    $search_form .= '<option value="">&nbsp;</option>';
                    $search_form .= $studylevel_list;
                    $search_form .= '</select>';
                    $search_form .= '</div>';
                    $search_form .= '</div>';

                }
                else if ($field->name == 'program_credithour')
                {

                    $search_form .= '<div class="form-group clearfix">';
                    $search_form .= '<div class="col-xs-3 col-xs-offset-0 col-md-2 col-md-offset-1 program_credithour">';
                    $search_form .= '' . __('Credit Hours', 'course-catalog-system') . '';
                    $search_form .= '</div>';
                    $search_form .= '<div class="col-xs-3 col-md-2">';
                    $search_form .= '<select id="program_credithour_filter" name="program_credithour_filter" style="width: 100%;">';
                    $search_form .= '<option value="eq">' . __('Equals to', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="ne">' . __('Not equal to', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="lt">' . __('Less than', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="le">' . __('Less than or equals to', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="gt">' . __('Greater than', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="ge">' . __('Greater than or equals to', 'course-catalog-system') . '</option>';
                    $search_form .= '</select>';
                    $search_form .= '</div>';
                    $search_form .= '<div class="col-xs-6 col-md-2">';
                    $search_form .= '<input type="text" id="program_credithour" name="program_credithour" maxlength="2">';
                    $search_form .= '</div>';
                    $search_form .= '<div class="hidden-sm col-md-5">&nbsp;</div>';
                    $search_form .= '</div>';

                }
                else if ($field->name == 'program_duration')
                {

                    $search_form .= '<div class="form-group clearfix">';
                    $search_form .= '<div class="col-xs-3 col-xs-offset-0 col-md-2 col-md-offset-1 program_duration">';
                    $search_form .= '' . __('Programme Length', 'course-catalog-system') . '';
                    $search_form .= '</div>';
                    $search_form .= '<div class="col-xs-3 col-md-2">';
                    $search_form .= '<select id="program_duration_filter" name="program_duration_filter" style="width: 100%;">';
                    $search_form .= '<option value="eq">' . __('Equals to', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="ne">' . __('Not equal to', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="lt">' . __('Less than', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="le">' . __('Less than or equals to', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="gt">' . __('Greater than', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="ge">' . __('Greater than or equals to', 'course-catalog-system') . '</option>';
                    $search_form .= '</select>';
                    $search_form .= '</div>';
                    $search_form .= '<div class="col-xs-2 col-md-2">';
                    $search_form .= '<input type="text" id="program_duration" name="program_duration" maxlength="2">';
                    $search_form .= '</div>';
                    $search_form .= '<div class="col-xs-4 col-md-2">';
                    $search_form .= '<select id="program_duration_type" name="program_duration_type">';
                    $search_form .= '<option value="yr">' . __('Year', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="sem">' . __('Semester', 'course-catalog-system') . '</option>';
                    $search_form .= '</select>';
                    $search_form .= '</div>';
                    $search_form .= '<div class="hidden-sm col-md-3">&nbsp;</div>';
                    $search_form .= '</div>';

                }
                else if ($field->name == 'program_type')
                {

                    $search_form .= '<div class="form-group clearfix">';
                    $search_form .= '<div class="col-xs-3 col-xs-offset-0 col-md-2 col-md-offset-1 program_type">';
                    $search_form .= '' . __('Programme Type', 'course-catalog-system') . '';
                    $search_form .= '</div>';
                    $search_form .= '<div class="col-xs-3 col-md-2">';
                    $search_form .= '<select id="program_type_filter" name="program_type_filter" style="width: 100%;">';
                    $search_form .= '<option value="eq">' . __('Equals to', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="ne">' . __('Not equal to', 'course-catalog-system') . '</option>';
                    $search_form .= '</select>';
                    $search_form .= '</div>';
                    $search_form .= '<div class="col-xs-6 col-md-2">';
                    $search_form .= '<select id="program_type" name="program_type">';
                    $search_form .= '<option value="">&nbsp;</option>';
                    $search_form .= '<option value="F">' . __('Full Time', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="P">' . __('Part Time', 'course-catalog-system') . '</option>';
                    $search_form .= '</select>';
                    $search_form .= '</div>';
                    $search_form .= '<div class="hidden-sm col-md-3">&nbsp;</div>';
                    $search_form .= '</div>';

                }
                else if ($field->name == 'study_mode')
                {

                    $search_form .= '<div class="form-group clearfix">';
                    $search_form .= '<div class="col-xs-3 col-xs-offset-0 col-md-2 col-md-offset-1 study_mode">';
                    //$search_form .= '' . __('Study Mode', 'course-catalog-system') . '';
                    $search_form .= '' . __('Programme Option', 'course-catalog-system') . '';
                    $search_form .= '</div>';
                    $search_form .= '<div class="col-xs-3 col-md-2">';
                    $search_form .= '<select id="study_mode_filter" name="study_mode_filter" style="width: 100%;">';
                    $search_form .= '<option value="eq">' . __('Equals to', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="ne">' . __('Not equal to', 'course-catalog-system') . '</option>';
                    $search_form .= '</select>';
                    $search_form .= '</div>';
                    $search_form .= '<div class="col-xs-6 col-md-3">';
                    $search_form .= '<select id="study_mode" name="study_mode">';
                    $search_form .= '<option value="">&nbsp;</option>';
                    $search_form .= '<option value="R">' . __('By Research', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="C">' . __('By Coursework', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="M">' . __('By Mixed Mode', 'course-catalog-system') . '</option>';
                    $search_form .= '</select>';
                    $search_form .= '</div>';
                    $search_form .= '<div class="hidden-sm col-md-3">&nbsp;</div>';
                    $search_form .= '</div>';

                }
                else if ($field->name == 'program_description')
                {

                    $search_form .= '<div class="form-group clearfix">';
                    $search_form .= '<div class="col-xs-3 col-xs-offset-0 col-md-2 col-md-offset-1 program_description">';
                    $search_form .= '' . __('Description', 'course-catalog-system') . '';
                    $search_form .= '</div>';
                    $search_form .= '<div class="col-xs-3 col-md-2">';
                    $search_form .= '<select id="program_description_filter" name="program_description_filter" style="width: 100%;">';
                    $search_form .= '<option value="ct">' . __('Contains', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="nc">' . __('Does not contain', 'course-catalog-system') . '</option>';
                    $search_form .= '</select>';
                    $search_form .= '</div>';
                    $search_form .= '<div class="col-xs-6 col-md-6">';
                    $search_form .= '<input type="text" id="program_description" name="program_description">';
                    $search_form .= '</div>';
                    $search_form .= '</div>';

                }
                else if ($field->name == 'program_careerprospect')
                {

                    $search_form .= '<div class="form-group clearfix">';
                    $search_form .= '<div class="col-xs-3 col-xs-offset-0 col-md-2 col-md-offset-1 program_careerprospect">';
                    $search_form .= '' . __('Career Prospects', 'course-catalog-system') . '';
                    $search_form .= '</div>';
                    $search_form .= '<div class="col-xs-3 col-md-2">';
                    $search_form .= '<select id="program_careerprospect_filter" name="program_careerprospect_filter" style="width: 100%;">';
                    $search_form .= '<option value="ct">' . __('Contains', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="nc">' . __('Does not contain', 'course-catalog-system') . '</option>';
                    $search_form .= '</select>';
                    $search_form .= '</div>';
                    $search_form .= '<div class="col-xs-6 col-md-6">';
                    $search_form .= '<input type="text" id="program_careerprospect" name="program_careerprospect">';
                    $search_form .= '</div>';
                    $search_form .= '</div>';

                }
                else if ($field->name == 'program_tags')
                {

                    $search_form .= '<div class="form-group clearfix">';
                    $search_form .= '<div class="col-xs-3 col-xs-offset-0 col-md-2 col-md-offset-1 program_tags">';
                    $search_form .= '' . __('Tags', 'course-catalog-system') . '';
                    $search_form .= '</div>';
                    $search_form .= '<div class="col-xs-3 col-md-2">';
                    $search_form .= '<select id="program_tags_filter" name="program_tags_filter" style="width: 100%;">';
                    $search_form .= '<option value="ct">' . __('Contains', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="eq">' . __('Equals to', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="ne">' . __('Not equal to', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="sw">' . __('Starts with', 'course-catalog-system') . '</option>';
                    $search_form .= '<option value="ew">' . __('Ends with', 'course-catalog-system') . '</option>';
                    $search_form .= '</select>';
                    $search_form .= '</div>';
                    $search_form .= '<div class="col-xs-6 col-md-6">';
                    $search_form .= '<input type="text" id="program_tags" name="program_tags">';
                    $search_form .= '</div>';
                    $search_form .= '<div class="hidden-sm col-md-3">&nbsp;</div>';
                    $search_form .= '</div>';

                }
            }

            $search_form .= '<br>';
            $search_form .= '<div class="form-group clearfix">';
            $search_form .= '<div class="col-xs-3 col-xs-offset-0 col-md-2 col-md-offset-1">';
            $search_form .= '&nbsp;';
            $search_form .= '</div>';
            $search_form .= '<div class="col-xs-8 col-md-8">';
            $search_form .= do_shortcode('[button type="default" shape="default" icon="fa-search" id="btn_search"]' . __('Search', 'course-catalog-system') . '[/button]');
            $search_form .= '<input type="hidden" name="search" value="1">';
            $search_form .= '</div>';
            $search_form .= '</div>';

            $search_form .= '</form>';
            $search_form .= '<script type="text/javascript">';
            $search_form .= 'jQuery(\'#btn_search\').on(\'click\', function() {';
            $search_form .= 'jQuery(\'#ccs_search_form\').submit();';
            $search_form .= '});';
            $search_form .= '</script>';

            // -- Search form init end

            $search_form = do_shortcode('[tagline_box highlightposition="top" margin_bottom="20px"]' . $search_form . '[/tagline_box]');
            //$search_form = eval("? >$search_form");

//            $search_result = file_get_contents(CCS_SEARCH_RESULT);
//
//            if ($search_result !== FALSE)
//            {
//                $search_result = eval("? >$search_result");
//            }
//            else
//            {
//                $search_result = '';
//            }
//
//            return $search_form . $search_result;

            return $search_form;
        }
        else
        {
            // Show search result

            $queries = $_POST;						// Array
            $queries['lang'] = $lang;

            $remote_url = $ccs_url . '/data/search_program_advance';
            $response = ccs_post_content_curl($remote_url, $queries);

            $json_data = $response['html'];
            $programs = json_decode($json_data);

            $output = '';
            $count_local = 0;

            if (count($programs) > 0)
            {
                // Filters
                $remote_url = $ccs_url . '/data/search_program_filter';
                $response = ccs_post_content_curl($remote_url, $queries);

                $data = $response['html'];
                $filter_str = json_decode($data);

                $output .= '<div class="search_criteria">';
                $output .= '<div style="line-height: 30px; background-color: #f4f4f6; padding: 5px 30px; margin: 0 0 15px;">';
                $output .= '<h3>' . __('Search Criteria:', 'course-catalog-system') . '</h3>';
                $output .= '<ul>';

                foreach ($filter_str as $row)
                {
                    $output .= '<li>' . str_replace('__OR__', __('OR'), $row->filter) . '</li>';
                }
                $output .= '</ul>';
                $output .= '</div>';
                $output .= '</div>';

                $output .= '<div class="table-1 search_result ccs" id="ccs_search_result">';
                $output .= '<table width="100%">';
                $output .= '<thead>';
                $output .= '<tr>';
                $output .= '<th style="width: 5%;">&nbsp;</th>';
                if ($queries['studylevel_id'] == '')
                {
                    $output .= '<th class="th_studylevel">' . __('Level of Study', 'course-catalog-system') . '</th>';
                }
                $output .= '<th>' . __('Programme', 'course-catalog-system') . '</th>';
                if ($queries['faculty_id'] == '')
                {
                    $output .= '<th class="th_faculty">' . __('Faculty', 'course-catalog-system') . '</th>';
                }
                $output .= '</tr>';
                $output .= '</thead>';
                $output .= '<tbody>';

                $cnt = 1;

                foreach ($programs as $program)
                {
                    $output .= '<tr>';
                    $output .= '<td style="text-align: center;">' . $cnt . '</td>';
                    if ($queries['studylevel_id'] == '')
                    {
                        $output .= '<td>' . $program->studylevel_name . '</td>';
                    }

                    $output .= '<td>';
                    if ($program->program_scope == 'L')
                    {
                        $output .= '<span style="color:red;">*</span>&nbsp;';
                        $count_local++;
                    }
                    if ( ! empty($program->program_code))
                    {
                        $output .= $program->program_code . ': ';
                    }

                    $output .= '<a href="' . get_site_url() . $ccs_program_details_page . '?' . $ccs_program_id_param . '=' . $program->program_id . '">';
                    $output .= $program->program_name;
                    $output .= '</a>';
                    $output .= '</td>';

                    if ($queries['faculty_id'] == '')
                    {
                        $output .= '<td>' . $program->faculty_name . '</td>';
                    }

                    $output .= '</tr>';
                    $cnt++;
                }

                $output .= '</tbody>';
                $output .= '</table>';
                $output .= '</div>';

                if ($count_local > 0)
                {
                    $output .= '<div class="ccs-text ccs-note">';
                    $output .= '<br>';
                    $output .= __('Programme marked (', 'course-catalog-system') . '<span style="color:red;">*</span>';
                    $output .= __(') are not available for international students', 'course-catalog-system');
                    $output .= '</div>';
                }
            }
            else
            {
                $output .= __('No result', 'course-catalog-system');
            }

            $output .= '<div class="new_search">';
            $output .= '<br>';
            $output .= do_shortcode('[button type="default" shape="default" icon="fa-search" id="btn_new_search" link="' . get_site_url() . $ccs_program_search_page . '"]' . __('New Search') . '[/button]');
            $output .= '</div>';

            $output .= '<script type="text/javascript">';
            $output .= "var p = jQuery('.search_criteria').siblings('p');";
            $output .= 'jQuery(p).each(function(index) { if (jQuery(this).text() == "") jQuery(p).remove()});';
            $output .= '</script>';

            return $output;
        }
    }
    else
    {
        return ccs_search_box_process_new();
    }
}
add_shortcode('ccs_render_search_program', 'ccs_render_search_program');

function get_filter_string($filter)
{
    switch ($filter)
    {
        case 'eq':
            return __('Equals to', 'course-catalog-system');
            break;
        case 'ne':
            return __('Not equal to', 'course-catalog-system');
            break;
        case 'le':
            return __('Less than or equals to', 'course-catalog-system');
            break;
        case 'lt':
            return __('Less than', 'course-catalog-system');
            break;
        case 'ge':
            return __('Greater than or equals to', 'course-catalog-system');
            break;
        case 'gt':
            return __('Greater than', 'course-catalog-system');
            break;
        case 'ct':
            return __('Contains', 'course-catalog-system');
            break;
        case 'sw':
            return __('Starts with', 'course-catalog-system');
            break;
        case 'ew':
            return __('Ends with', 'course-catalog-system');
            break;
        default:
            return '';
            break;
    }
}

function ccs_render_search_box($atts)
{
    $attributes = shortcode_atts(array(
        'border' => 'none'			// Default to Undergraduate Studies
    ), $atts);

    if (defined('ICL_LANGUAGE_CODE'))
    {
        $lang = ICL_LANGUAGE_CODE;
    }
    else
    {
        if (function_exists('qtranxf_getLanguage'))
        {
            $lang = qtranxf_getLanguage();
        }
        else
        {
            $lang = 'en';
        }
    }

    // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
    // Each __() function must be __('Words to translate', 'course-catalog-system')
    load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

    $options = get_option(CCS_OPTION_NAME);
    $ccs_url = $options['ccs_url'];
    $ccs_program_search_page = $options['ccs_program_search_page'];

    $search_box = file_get_contents(CCS_SEARCH_BOX);

    if ($search_box !== FALSE)
    {
        $search_box = str_replace('<!--{{SEARCH_PAGE}}-->', get_site_url() . $ccs_program_search_page, $search_box);
        $search_box = str_replace('<!--{{SEARCH_LABEL}}-->', __('Find a Course', 'course-catalog-system'), $search_box);
        $search_box = str_replace('<!--{{SEARCH_BUTTON}}-->', __('Search', 'course-catalog-system'), $search_box);

        $border = 'none';
        if (in_array($attributes['border'], array('top', 'bottom', 'left', 'right')))
        {
            $border = $attributes['border'];
        }

        $search_box = do_shortcode('[tagline_box highlightposition="' . $border . '" margin_top="0px" margin_bottom="0px"]' . $search_box . '[/tagline_box]');

        // WARNING: Using the following code (eval) will make the output appear at the top of the page!!!
        //$search_box = eval("? >$search_box");

        return $search_box . eol();
    }

    return '';
}
add_shortcode('ccs_render_search_box', 'ccs_render_search_box');

/**
 * Show search from simple search
 */
function ccs_search_box_process_new()
{
    if (isset($_GET['query']))
    {
        if (defined('ICL_LANGUAGE_CODE'))
        {
            $lang = ICL_LANGUAGE_CODE;
        }
        else
        {
            if (function_exists('qtranxf_getLanguage'))
            {
                $lang = qtranxf_getLanguage();
            }
            else
            {
                $lang = 'en';
            }
        }

        // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
        // Each __() function must be __('Words to translate', 'course-catalog-system')
        load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

        $options = get_option(CCS_OPTION_NAME);
        $ccs_url = $options['ccs_url'];
        $ccs_program_details_page = $options['ccs_program_details_page'];
        $ccs_program_id_param = $options['ccs_program_id_param'];
        $ccs_program_search_page = $options['ccs_program_search_page'];

        $query = $_GET['query'];
        $query = str_replace(' ', '%2B', $query);

        $remote_url = $ccs_url . '/api/wordpress/search_program/' . $query . '/' . $lang;
        $response = ccs_get_content_curl($remote_url);

        $json_data = $response['html'];
        $programs = json_decode($json_data);

        $output = '';
        $result = '';

        if (count($programs) > 0)
        {
//            $search_result_top = file_get_contents(CCS_SEARCH_RESULT_TOP);
//
//            if ($search_result_top === FALSE)
//            {
//                $search_result_top = '';
//            }
//            else
//            {
//                $search_result_top = str_replace('<!--{{FACULTY}}-->', __('Faculty', 'course-catalog-system'), $search_result_top);
//                $search_result_top = str_replace('<!--{{STUDYLEVEL}}-->', __('Faculty', 'course-catalog-system'), $search_result_top);
//                $search_result_top = str_replace('<!--{{PROGRAMME}}-->', __('Faculty', 'course-catalog-system'), $search_result_top);
//            }

            $search_result_top  = '<div class="new_search">';
            $search_result_top .= '<div class="search_criteria" style="line-height: 30px; background-color: #f4f4f6; padding: 5px 30px; margin: 15px 0;">';
            $search_result_top .= '<h3>' . __('Search Criteria:', 'course-catalog-system') . '</h3>';

            $query = $_GET['query'];
            $queries = explode(' ' , $query);
            $query_filters = '';

            for ($a = 0; $a < count($queries); $a++)
            {
                if ($a == 0)
                {
                    $query_filters = '&#39;' . $queries[$a] . '&#39;';
                }
                else
                {
                    $query_filters .= ' ' . __('OR') . ' &#39;' . $queries[$a] . '&#39;';
                }
            }
            $search_result_top .= '<ul>';
            $search_result_top .= '<li>' . __('Tags contains') . ' ' . $query_filters . '</li>';
            $search_result_top .= '</ul>';

            $search_result_top .= '</div>';
            $search_result_top .= '</div>';
            $search_result_top .= '<div class="table-1 search_result ccs" id="ccs_search_result">';
            $search_result_top .= '<table width="100%">';
            $search_result_top .= '<thead>';
            $search_result_top .= '<tr>';
            $search_result_top .= '<th style="width: 5%;">&nbsp;</th>';
            $search_result_top .= '<th class="th_faculty">' . __('Faculty', 'course-catalog-system') . '</th>';
            $search_result_top .= '<th class="th_studylevel">' . __('Level of Study', 'course-catalog-system') . '</th>';
            $search_result_top .= '<th>' . __('Programme', 'course-catalog-system') . '</th>';
            $search_result_top .= '</tr>';
            $search_result_top .= '</thead>';
            $search_result_top .= '<tbody>';

            $cnt = 0;
            $local = 0;

            foreach ($programs as $program)
            {
                $cnt++;
                $result .= 	'<tr>' .
                                '<td style="text-align: center;">' . $cnt . '</td>' .
                                '<td>' . $program->faculty_name . '</td>' .
                                '<td>' . $program->studylevel_name . '</td>' .
                                '<td>' .
                                '<a href="' . get_site_url() . $ccs_program_details_page . '?' . $ccs_program_id_param . '=' . $program->program_id . '">' .
                                ($program->program_scope == 'L' ? '<span style="color:red;">*</span>&nbsp;' : '')  .
                                (($program->program_code != '' && $program->program_code != null) ? $program->program_code . ': ' : '') .
                                $program->program_name . '</a>' .
                                '</td>' .
                            '</tr>';
                if ($program->program_scope == 'L')
                {
                    $local++;
                }
            }

//            $search_result_bottom = file_get_contents(CCS_SEARCH_RESULT_BOTTOM);
//
//            if ($search_result_bottom === FALSE)
//            {
//                $search_result_bottom = '';
//            }

            $search_result_bottom  = '</tbody>';
            $search_result_bottom .= '</table>';
            $search_result_bottom .= '</div>';

            if ($local > 0)
            {
                $search_result_bottom .= '<div class="ccs-text ccs-note">';
                $search_result_bottom .= '<br>';
                $search_result_bottom .= __('Programme marked (', 'course-catalog-system') . '<span style="color:red;">*</span>';
                $search_result_bottom .= __(') are not available for international students', 'course-catalog-system');
                $search_result_bottom .= '</div>';
            }

            $search_result_bottom .= '<div class="new_search">';
            $search_result_bottom .= '<br>';
            $search_result_bottom .= do_shortcode('[button type="default" shape="default" icon="fa-search" id="btn_new_search" link="' . get_site_url() . $ccs_program_search_page . '"]' . __('New Search') . '[/button]');
            $search_result_bottom .= '</div>';

            //$output .= eval("? >$search_result_top" . "$result" . "$search_result_bottom");
            $output .= $search_result_top . $result . $search_result_bottom;

            return $output;
        }
        else
        {
//            $search_no_result = file_get_contents(CCS_SEARCH_NO_RESULT);
//
//            if ($search_no_result !== FALSE)
//            {
//                $search_no_result = eval("? >$search_no_result");
//            }
//            else
//            {
//                $search_no_result = __('No result', 'course-catalog-system');
//            }

            $search_no_result  = __('No result', 'course-catalog-system');

            $search_no_result .= '<div class="new_search">';
            $search_no_result .= '<br>';
            $search_no_result .= do_shortcode('[button type="default" shape="default" icon="fa-search" id="btn_new_search" link="' . get_site_url() . $ccs_program_search_page . '"]' . __('New Search') . '[/button]');
            $search_no_result .= '</div>';

            return $search_no_result;
        }
    }
    else
    {
        return '';
    }
}

function ccs_search_box_process()
{
    return '';
}
add_shortcode('ccs_search_box_process', 'ccs_search_box_process');

/**
 * List programme contents by content id, the position is set on Wordpress page
 */
function ccs_render_program_content($atts)
{
    // /api/wordpress/htmlcontent/{program_id}/{content_id}

    if (defined('ICL_LANGUAGE_CODE'))
    {
        $lang = ICL_LANGUAGE_CODE;
    }
    else
    {
        if (function_exists('qtranxf_getLanguage'))
        {
            $lang = qtranxf_getLanguage();
        }
        else
        {
            $lang = 'en';
        }
    }

    // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
    // Each __() function must be __('Words to translate', 'course-catalog-system')
    load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

    $attributes = shortcode_atts(array(
        'content_id' => '',
        'width' => '400',
        'height' => '300',
        'align' => 'left',
        'autoplay' => 'no',
        'box' => 'false'
    ), $atts);

    $options = get_option(CCS_OPTION_NAME);
    $ccs_url = $options['ccs_url'];
    $ccs_faculty_id_param = $options['ccs_faculty_id_param'];
    $ccs_program_id_param = $options['ccs_program_id_param'];
    $text_align = (isset($attributes['align']) ? $attributes['align'] : '');

    $pid = isset( $_GET[$ccs_program_id_param] ) ? $_GET[$ccs_program_id_param] : '';

    $output = '';

    if ( ! empty($pid) && ! empty($attributes['content_id']))
    {
        $remote_url = $options['ccs_url'] . '/api/wordpress/htmlcontent/' . $pid . '/' . $attributes['content_id'] . '/' . $lang;

        $response = ccs_get_content_curl($remote_url);

        $json_data = $response['html'];
        $program_contents = json_decode($json_data);

        foreach ($program_contents as $program_content)
        {
            if ( ! empty($program_content->content_description))
            {
                if ($program_content->content_type == 'I')
                {
                    if (empty($text_align))
                    {
                        $output .= '<img src="' . $program_content->content_description . '" alt="">';
                    }
                    else
                    {
                        $output .= '<div style="text-align:' . $text_align . ';">' . '<img src="' . $program_content->content_description . '" alt="">' . '</div>';
                    }
                }
                else if ($program_content->content_type == 'V')
                {
                    if (stripos($program_content->content_description, 'youtube.com/') !== false)
                    {
                        $video_id = '';
                        if (stripos($program_content->content_description, '/embed/') !== false)
                        {
                            $video_id = substr($program_content->content_description, stripos($program_content->content_description, '/embed/') + strlen('/embed/'));
                        }
                        else if (stripos($program_content->content_description, '?v=') !== false)
                        {
                            $video_id = substr($program_content->content_description, stripos($program_content->content_description, '?v=') + strlen('?v='));
                        }
                        else if (stripos($program_content->content_description, '&v=') !== false)
                        {
                            $video_id = substr($program_content->content_description, stripos($program_content->content_description, '&v=') + strlen('&v='));
                        }

                        if (stripos($video_id, '&') !== false)
                        {
                            $video_id = substr($video_id, 0, stripos($video_id, '&'));
                        }

                        if ( ! empty($video_id))
                        {
                            if (empty($text_align))
                            {
                                $output .= do_shortcode('[youtube id="' . $video_id . '" width="' . $attributes['width'] . '" height="' . $attributes['height'] . '" autoplay="' . $attributes['autoplay'] . '"]');
                            }
                            else
                            {
                                $output .= '<div style="text-align:' . $text_align . ';">' . do_shortcode('[youtube id="' . $video_id . '" width="' . $attributes['width'] . '" height="' . $attributes['height'] . '" autoplay="' . $attributes['autoplay'] . '"]') . '</div>';
                            }
                        }
                    }
                    else if (stripos($program_content->content_description, 'vimeo.com/') !== false)
                    {
                        $video_id = '';
                        if (stripos($program_content->content_description, 'vimeo.com/') !== false)
                        {
                            $video_id = substr($program_content->content_description, stripos($program_content->content_description, 'vimeo.com/') + strlen('vimeo.com/'));
                        }

                        if (stripos($video_id, '&') !== false)
                        {
                            $video_id = substr($video_id, 0, stripos($video_id, '&'));
                        }

                        if (stripos($video_id, '?') !== false)
                        {
                            $video_id = substr($video_id, 0, stripos($video_id, '?'));
                        }

                        if ( ! empty($video_id))
                        {
                            if (empty($text_align))
                            {
                                $output .= do_shortcode('[vimeo id="' . $video_id . '" width="' . $attributes['width'] . '" height="' . $attributes['height'] . '" autoplay="' . $attributes['autoplay'] . '"]');
                            }
                            else
                            {
                                $output .= '<div style="text-align:' . $text_align . ';">' . do_shortcode('[vimeo id="' . $video_id . '" width="' . $attributes['width'] . '" height="' . $attributes['height'] . '" autoplay="' . $attributes['autoplay'] . '"]') . '</div>';
                            }
                        }
                    }
                    else
                    {
                        if (empty($text_align))
                        {
                            $output .= '<iframe src="' . $program_content->content_description . '" width="' . $attributes['width'] . '" height="' . $attributes['height'] . '" type="text/html" frameborder="0"></iframe>';
                        }
                        else
                        {
                            $output .= '<div style="text-align:' . $text_align . ';">' . '<iframe src="' . $program_content->content_description . '" width="' . $attributes['width'] . '" height="' . $attributes['height'] . '" type="text/html" frameborder="0"></iframe>' . '</div>';
                        }
                    }
                }
                else
                {
                    if (empty($text_align))
                    {
                        $output .= '<div>' . do_shortcode($program_content->content_description) . '</div>';
                    }
                    else
                    {
                        $output .= '<div style="text-align:' . $text_align . ';">' . do_shortcode($program_content->content_description) . '</div>';
                    }
                }
            }
        }
    }

    if ( ! empty($output))
    {
        if ($attributes['box'] == 'true')
        {
            return do_shortcode('[tagline_box highlightposition="top" margin_bottom="20px"]' . $output . '[/tagline_box]');
        }
    }

    return $output;
}
add_shortcode('ccs_render_program_content', 'ccs_render_program_content');

/* Testing */
function ccs_get_lang($atts)
{
    if (defined('ICL_LANGUAGE_CODE'))
    {
        $lang = ICL_LANGUAGE_CODE;
    }
    else
    {
        if (function_exists('qtranxf_getLanguage'))
        {
            $lang = qtranxf_getLanguage();
        }
        else
        {
            $lang = 'en';
        }
    }

    // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
    // Each __() function must be __('Words to translate', 'course-catalog-system')
    load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

    $options = get_option(CCS_OPTION_NAME);

    $ccs_url = $options['ccs_url'] . '/api/wordpress/faculties/' . $lang;

    return 'lang = ' . $lang . ', ccs_url = ' . $ccs_url;
}
add_shortcode('ccs_get_lang', 'ccs_get_lang');

function eol() { return '<!-- Programme Catalog System plugin by Nizma Resources (http://www.nizma.com.my) -->'; }
